@@ -102,12 +102,11 @@ import yaml
 import salt.ext.six as six
 import salt.utils
 import salt.client
+from salt.utils.openstack import nova
 try:
-    from salt.utils.openstack import nova
     import novaclient.exceptions
-    HAS_NOVA = True
-except NameError as exc:
-    HAS_NOVA = False
+except ImportError as exc:
+    pass
 
 # Import Salt Cloud Libs
 from salt.cloud.libcloudfuncs import *  # pylint: disable=W0614,W0401
@@ -174,9 +173,8 @@ def get_dependencies():
     Warn if dependencies aren't met.
     '''
     deps = {
-        'libcloud': HAS_LIBCLOUD,
         'netaddr': HAS_NETADDR,
-        'nova': HAS_NOVA,
+        'python-novaclient': nova.check_nova(),
     }
     return config.check_driver_dependencies(
         __virtualname__,
@@ -646,7 +644,7 @@ def create(vm_):
             return
 
         rackconnectv3 = config.get_cloud_config_value(
-            'rackconnectv3', vm_, __opts__, default='False',
+            'rackconnectv3', vm_, __opts__, default=False,
             search_global=False
         )
 
@@ -722,21 +720,29 @@ def create(vm_):
             data.public_ips = access_ip
             return data
 
+        # populate return data with private_ips
+        # when ssh_interface is set to private_ips and public_ips exist
+        if not result and ssh_interface(vm_) == 'private_ips':
+            for private_ip in private:
+                ignore_ip = ignore_cidr(vm_, private_ip)
+                if private_ip not in data.private_ips and not ignore_ip:
+                    result.append(private_ip)
+
         if cloudnetwork(vm_) is True:
             data.public_ips = access_ip
             return data
 
+        if public:
+            data.public_ips = public
+            if ssh_interface(vm_) != 'private_ips':
+                return data
+
         if result:
             log.debug('result = {0}'.format(result))
             data.private_ips = result
             if ssh_interface(vm_) == 'private_ips':
                 return data
 
-        if public:
-            data.public_ips = public
-            if ssh_interface(vm_) != 'private_ips':
-                return data
-
     try:
         data = salt.utils.cloud.wait_for_ip(
             __query_node_data,
