@@ -655,7 +655,7 @@ def run(cmd,
         Shell to execute under. Defaults to the system default shell.
 
     python_shell
-        If True, let python handle the positional arguments. Set to False
+        If False, let python handle the positional arguments. Set to True
         to use shell features, such as pipes or redirection
 
     env
@@ -1064,7 +1064,7 @@ def run_stdout(cmd,
         Shell to execute under. Defaults to the system default shell.
 
     python_shell
-        If True, let python handle the positional arguments. Set to False
+        If False, let python handle the positional arguments. Set to True
         to use shell features, such as pipes or redirection
 
     env
@@ -1247,7 +1247,7 @@ def run_stderr(cmd,
         Shell to execute under. Defaults to the system default shell.
 
     python_shell
-        If True, let python handle the positional arguments. Set to False
+        If False, let python handle the positional arguments. Set to True
         to use shell features, such as pipes or redirection
 
     env
@@ -1406,6 +1406,7 @@ def run_all(cmd,
             ignore_retcode=False,
             saltenv='base',
             use_vt=False,
+            redirect_stderr=False,
             **kwargs):
     '''
     Execute the passed command and return a dict of return data
@@ -1429,7 +1430,7 @@ def run_all(cmd,
         Shell to execute under. Defaults to the system default shell.
 
     python_shell
-        If True, let python handle the positional arguments. Set to False
+        If False, let python handle the positional arguments. Set to True
         to use shell features, such as pipes or redirection
 
     env
@@ -1504,6 +1505,14 @@ def run_all(cmd,
     Note that ``env`` represents the environment variables for the command, and
     should be formatted as a dict, or a YAML string which resolves to a dict.
 
+    redirect_stderr : False
+        If set to ``True``, then stderr will be redirected to stdout. This is
+        helpful for cases where obtaining both the retcode and output is
+        desired, but it is not desired to have the output separated into both
+        stdout and stderr.
+
+        .. versionadded:: 2015.8.2
+
     CLI Example:
 
     .. code-block:: bash
@@ -1528,10 +1537,12 @@ def run_all(cmd,
     '''
     python_shell = _python_shell_default(python_shell,
                                          kwargs.get('__pub_jid', ''))
+    stderr = subprocess.STDOUT if redirect_stderr else subprocess.PIPE
     ret = _run(cmd,
                runas=runas,
                cwd=cwd,
                stdin=stdin,
+               stderr=stderr,
                shell=shell,
                python_shell=python_shell,
                env=env,
@@ -1610,7 +1621,7 @@ def retcode(cmd,
         Shell to execute under. Defaults to the system default shell.
 
     python_shell
-        If True, let python handle the positional arguments. Set to False
+        If False, let python handle the positional arguments. Set to True
         to use shell features, such as pipes or redirection
 
     env
@@ -1844,7 +1855,7 @@ def script(source,
         Shell to execute under. Defaults to the system default shell.
 
     python_shell
-        If True, let python handle the positional arguments. Set to False
+        If False, let python handle the positional arguments. Set to True
         to use shell features, such as pipes or redirection
 
     env
@@ -2057,7 +2068,7 @@ def script_retcode(source,
         Shell to execute under. Defaults to the system default shell.
 
     python_shell
-        If True, let python handle the positional arguments. Set to False
+        If False, let python handle the positional arguments. Set to True
         to use shell features, such as pipes or redirection
 
     env
@@ -2320,7 +2331,7 @@ def run_chroot(root,
         Shell to execute under. Defaults to the system default shell.
 
     python_shell
-        If True, let python handle the positional arguments. Set to False
+        If False, let python handle the positional arguments. Set to True
         to use shell features, such as pipes or redirection
 
     env
