@@ -26,6 +26,11 @@ log = logging.getLogger(__name__)
 
 from salt.exceptions import SaltInvocationError
 
+# Don't shadow built-ins.
+__func_alias__ = {
+    'list_': 'list'
+}
+
 __virtualname__ = 'consul'
 
 
@@ -92,7 +97,7 @@ def _query(function,
     return ret
 
 
-def list(consul_url=None, key=None, **kwargs):
+def list_(consul_url=None, key=None, **kwargs):
     '''
     List keys in Consul
 
@@ -2032,7 +2037,7 @@ def acl_update(consul_url=None, **kwargs):
     if 'id' in kwargs:
         data['ID'] = kwargs['id']
     else:
-        ret['message'] = 'Required paramter "id" is missing.'
+        ret['message'] = 'Required parameter "id" is missing.'
         ret['res'] = False
         return ret
 
@@ -2088,7 +2093,7 @@ def acl_delete(consul_url=None, **kwargs):
             return ret
 
     if 'id' not in kwargs:
-        ret['message'] = 'Required paramter "id" is missing.'
+        ret['message'] = 'Required parameter "id" is missing.'
         ret['res'] = False
         return ret
 
@@ -2135,7 +2140,7 @@ def acl_info(consul_url=None, **kwargs):
             return ret
 
     if 'id' not in kwargs:
-        ret['message'] = 'Required paramter "id" is missing.'
+        ret['message'] = 'Required parameter "id" is missing.'
         ret['res'] = False
         return ret
 
@@ -2174,7 +2179,7 @@ def acl_clone(consul_url=None, **kwargs):
             return ret
 
     if 'id' not in kwargs:
-        ret['message'] = 'Required paramter "id" is missing.'
+        ret['message'] = 'Required parameter "id" is missing.'
         ret['res'] = False
         return ret
 
@@ -2219,7 +2224,7 @@ def acl_list(consul_url=None, **kwargs):
             return ret
 
     if 'id' not in kwargs:
-        ret['message'] = 'Required paramter "id" is missing.'
+        ret['message'] = 'Required parameter "id" is missing.'
         ret['res'] = False
         return ret
 
